#
# spec file for package granite
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define sover 5
%define soname libgranite
%define _typelibdir %(pkg-config --variable=typelibdir gobject-introspection-1.0)
%define _girdir %(pkg-config --variable=girdir gobject-introspection-1.0)
Name:           granite
Version:        5.2.3
Release:        1.1
Summary:        An extension of GTK+ libraries
License:        LGPL-3.0-or-later and LGPL-3.0+
Group:          Development/Libraries/C and C++
URL:            https://elementary.io/
Source:         https://github.com/elementary/granite/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  meson >= 0.48.2
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  vala >= 0.28.0
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gthread-2.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22.0

%description
Granite is an extension of GTK+. Among other things, it provides the
commonly-used widgets such as modeswitchers, welcome screens, AppMenus,
search bars, and more found in Elementary applications.

%package -n     %{soname}%{sover}
Summary:        Granite is a development library
Group:          System/Libraries
Requires:       %{name}-common
Provides:       %{name} = %{version}

%description -n %{soname}%{sover}
Granite is an extension of GTK+. It provides the commonly used widgets
found in Elementary applications.

%package        common
Summary:        Granite development library -- Common Files
Group:          System/Libraries
Recommends:     %{name}-lang

%description    common
Granite is an extension of GTK+.

This package contains the common files needed by the library.

%package        demo
Summary:        Granite development library -- Demo binary
Group:          Development/Libraries/Other

%description    demo
Granite is an extension of GTK+.

This package contains a small demo application to show the %{name} widgets.

%package -n     typelib-1_0-Granite-1_0
Summary:        Granite development library -- Introspection bindings
Group:          Development/Libraries/GNOME

%description -n typelib-1_0-Granite-1_0
Granite is an extension of GTK+.

This package provides the GObject Introspection bindings for %{soname}.

%package        devel
Summary:        Granite development library -- Development files
Group:          Development/Libraries/GNOME
Requires:       %{soname}%{sover} = %{version}

%description    devel
Granite is an extension of GTK+.

This package contains the development files for %{soname}.

%lang_package

%prep
%setup -q

# Fix: invalid-filepath-dependency
sed -e "s/libgranite.full_path.*\,$/'%{soname}.so.%{sover}',/" \
    -i $(grep -rl 'libgranite.full_path')

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{name}
%fdupes -s %{buildroot}%{_datadir}

%post   -n %{soname}%{sover} -p /sbin/ldconfig
%postun -n %{soname}%{sover} -p /sbin/ldconfig

%files -n %{soname}%{sover}
%{_libdir}/%{soname}.so.%{sover}*

%files common
%license COPYING
%doc AUTHORS README*
%{_datadir}/icons/hicolor/*/actions/appointment.??g
%{_datadir}/icons/hicolor/*/actions/open-menu*.??g

%files demo
%{_bindir}/%{name}-demo
%{_datadir}/applications/%{name}-demo.desktop

%files -n typelib-1_0-Granite-1_0
%{_typelibdir}/Granite-1.0.typelib

%files devel
%{_includedir}/%{name}/
%{_libdir}/%{soname}.so
%{_libdir}/pkgconfig/%{name}.pc
%{_girdir}/Granite-1.0.gir
%{_datadir}/vala/vapi/%{name}.deps
%{_datadir}/vala/vapi/%{name}.vapi

%files lang -f %{name}.lang

%changelog
* Thu Feb 28 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 5.2.3:
  * Require Meson >=0.48.2 Part 2 (#267)
  * meson: require meson >= 0.48.2 (#266)
  * TimePicker: Use more compact boolean comparison syntax (#260)
  * Fix typo on Avatar documentation (#259)
  * Add function to check if history is enabled within the
    privacy settings (#257)
  * MessageDialog: Add show_error_expander method (#205)
  * Handle 'Return' key (#255)
  * DateTime: strip leading spaces from time formats (#252)
  * meson: bring back the dependencies to the Require field of
    the pkgconfig
  * Switch from CMake to Meson build system (#240)
  * Ignore empty accel strings (#251)
* Wed Nov 21 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 5.2.1:
  * Utils: Make accels optional (#237)
  * Avoid List.copy() and transfer ownership to fix type-argument
    mismatch
* Fri Nov  2 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 5.2.0:
  * markup_accel_tooltip: Don't add duplicate accels (#235)
  * Handle plus/minus (#234)
  * Add utilities for marking up accel tooltips (#229)
  * TimePicker: Restore position_dropdown() to fix ABI/API break
  * Change settings to look at a more relevant value for time
    format (#222)
  * Demo: Move ModeSwitch to ModeButton page (#215)
  * StyleClass: add checkerboard (#214)
  * TimePicker: misc cleanup (#210)
  * Updated Example (#207)
* Mon Oct  8 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 5.1.0:
  * DateTime: Add commas in date format (#202)
  * Merge branch 'origin/master' into Weblate
  * Don't propagate right click in source list (#190)
  * .gitignore: Ignore temporary files
  * Deprecate Granite.Application (#196)
  * Add EditorConfig
  * Add Granite.ModeSwitch (#195)
  * GraniteDemo: Use Gtk.Application (#197)
  * Allow markup in SourceList.Item names (#188)
* Sat Jun  9 2018 avvissu@yandex.by
- Update to 5.0:
  * application: Do not export extern symbols
  * Use --target-glib=2.50 to match gtk+-3.0 requirement
  * Fix "copying delegates is not supported" warnings
  * AlertView: Hide icon if no icon name (#167)
  * Merge remote-tracking branch 'origin/master'
  * Style class mode switch (#186)
  * DynamicNotebook: Fix title case (#183)
  * Handle negative seconds in seconds_to_time function (#140)
  * Bump vala dependency to >= 0.40
  * DynamicNotebook: Disconnect from backing Gtk.Notebook on
    destroy
  * Drop default value of non-automatic property for vala 0.41+
  * SimpleSettingsPage: Hide action area if empty (#171)
  * DynamicNotebook: Style cleanups (#173)
  * SimpleSettingsPage: Valign title with no description (#170)
  * Remove several deprecation warnings and useless functions
    (#160)
  * SimpleSettingsPage: Ellipsize long page titles (#168)
  * Add code examples (#153)
  * Deprecate overlay property in OverlayBar (#162)
  * MessageDialog: Move properties to construct block (#165)
  * Prevent ModeButton deselection (for #67) (#156)
  * DynamicNotebook: make the keybinding trigger the right signal
    (#164)
* Fri Jun  8 2018 avvissu@yandex.by
- Update the homepage
- Spec file cleanup
* Mon Jan 22 2018 avvissu@yandex.by
- Add typelib-1_0-Granite-1_0 as required dependency
* Thu Nov  9 2017 avvissu@yandex.by
- Update license
* Sat Nov  4 2017 avvissu@yandex.by
- Update to 0.5:
  * Update FSF address (#126)
  * Allow subclassing Granite.Wigets.Tab (#124)
  * Major soname bump (#117)
  * Add Seekbar Widget (#120)
  * Replace deprecated margin_left and margin_right (#119)
  * Add SettingsSidebar (#70)
  * [DynamicNotebook] Use GObject construct method to allow
    subclasses (#118)
  * Update popover calendar when setting date (#113)
  * DynamicNotebook: Fix regression with tab duplication on close
  * add relative date time utils (#102)
  * DynamicNotebook: misc cleanup (#105)
  * Better parse text input (#115)
  * Fix parsing application options (#111)
  * Make settings lookup recursive (#103)
  * Add Date & Time formatting to the demo (#101)
  * Add primary style class (#100)
  * Add a Granite.MessageDialog (#98)
  * Fix handling debug option blocking other options from showing
    in help (#96)
* Sun May  7 2017 avvissu@yandex.by
- Update to 0.4.1:
  * Readme: Fix weblate link (#43)
  * Demo: update URLs (#42)
  * Make ModeButton use toggled instead of button_press_event
  * Switch WelcomeButton from button_release_event to clicked
  * Avatar: change icon_size to pixel_size (#37)
  * Merge remote-tracking branch 'origin/master'
  * StorageBar.vala: remove deprecated resize_children
  * Ignore arguments that aren't recognised by granite
  * Fix build with vala 0.35.6
  * lib/GtkPatch/AboutDialog.vala: unmark as executable
  * avatar: allow HiDPI Pixbufs (X times bigger raw images or
    icons specifically rendered for @X size)
  * Do not call set_prgname () while GLib already calls it
  * Add Toast.png to doc/images
  * Add 2017 to license copyright and app years.
  * DatePicker: add a "date_changed" signal
  * AlertView: Wrap title label
  * Demo: Use back-button style class
  * Update license header
  * Remove using Gtk
  * Add a Toast widget with demo
  * doc/CMakeLists.txt: fix make valadocs command
  * Use Gtk.STYLE_CLASS_VIEW
  * Use Gtk.STYLE_CLASS_DIM_LABEL
  * Add "welcome" style class
- Drop granite-0.4.0.1-vala-0.36.patch
* Sat Apr  1 2017 avvissu@yandex.by
- Fix build with vala >= 0.36 (granite-0.4.0.1-vala-0.36.patch)
* Thu Sep 22 2016 avvissu@yandex.by
- Fix install the lang pack
* Thu Sep 15 2016 avvissu@yandex.by
- Spec file cleanup
* Sat Sep 10 2016 mailaender@opensuse.org
- update to version 0.4.0.1
- add a lang package
* Sun Aug 30 2015 mailaender@opensuse.org
- update to version 0.3.1
- removed vala_gtk_bindings.patch as lp#1421925 is fixed upstream
- removed DynamicNotebook.diff as lp#1453526 has been fixed upstream
- removed ContractorView.diff
* Fri May 15 2015 mailaender@opensuse.org
- add patches to fix bit rot
  * ContractorView.diff
  * DynamicNotebook.diff
* Mon Feb 16 2015 mailaender@opensuse.org
- add vala_gtk_bindings.patch.patch to fix lp#1421925
* Sun Jun 15 2014 mailaender@opensuse.org
- update to version 0.3.0
* Thu May 15 2014 jengelh@inai.de
- initial packaging
